#
# This procedure tests the network on the training set, and on a set of regular words (testR),
# exception words (testE) and nonwords (testN); the results show, for each, the average error per
# example and the accuracy.  Here, accuracy is determined by having all output units on the correct
# side of 0.5 given their targets, rather than by having the decoded phoneme string match the
# correct one (as in the paper) .
#
proc testall { } {
  global Test
  set freq [getObj pseudoExampleFreq]
  setObj pseudoExampleFreq 0

  useTestingSet  testR
  test -r
  set errR $Test(exampleError)
  set accR $Test(percentCorrect)

  useTestingSet  testE
  test -r
  set errE $Test(exampleError)
  set accE $Test(percentCorrect)

  useTestingSet  testN
  test -r
  set errN $Test(exampleError)
  set accN $Test(percentCorrect)

  useTestingSet  train
  test -r
  setObj pseudoExampleFreq $freq

  puts "            Training        Regular      Exception        Nonword"
  puts "Epoch      err   acc      err   acc      err   acc      err   acc"
  puts [format {%5d    %5.3f %5.1f    %5.3f %5.1f    %5.3f %5.1f    %5.3f %5.1f} \
       [getObj totalUpdates] $Test(exampleError) $Test(percentCorrect) \
       $errR $accR $errE $accE $errN $accN]
}

setObj graphemes.unit(0).name	"Y"
setObj graphemes.unit(1).name	"S"
setObj graphemes.unit(2).name	"P"
setObj graphemes.unit(3).name	"T"
setObj graphemes.unit(4).name	"K"
setObj graphemes.unit(5).name	"Q"
setObj graphemes.unit(6).name	"C"
setObj graphemes.unit(7).name	"B"
setObj graphemes.unit(8).name	"D"
setObj graphemes.unit(9).name	"G"
setObj graphemes.unit(10).name	"F"
setObj graphemes.unit(11).name	"V"
setObj graphemes.unit(12).name	"J"
setObj graphemes.unit(13).name	"Z"
setObj graphemes.unit(14).name	"L"
setObj graphemes.unit(15).name	"M"
setObj graphemes.unit(16).name	"N"
setObj graphemes.unit(17).name	"R"
setObj graphemes.unit(18).name	"W"
setObj graphemes.unit(19).name	"H"
setObj graphemes.unit(20).name	"CH"
setObj graphemes.unit(21).name	"GH"
setObj graphemes.unit(22).name	"GN"
setObj graphemes.unit(23).name	"PH"
setObj graphemes.unit(24).name	"PS"
setObj graphemes.unit(25).name	"RH"
setObj graphemes.unit(26).name	"SH"
setObj graphemes.unit(27).name	"TH"
setObj graphemes.unit(28).name	"TS"
setObj graphemes.unit(29).name	"WH"
setObj graphemes.unit(30).name	"E"
setObj graphemes.unit(31).name	"I"
setObj graphemes.unit(32).name	"O"
setObj graphemes.unit(33).name	"U"
setObj graphemes.unit(34).name	"A"
setObj graphemes.unit(35).name	"Y"
setObj graphemes.unit(36).name	"AI"
setObj graphemes.unit(37).name	"AU"
setObj graphemes.unit(38).name	"AW"
setObj graphemes.unit(39).name	"AY"
setObj graphemes.unit(40).name	"EA"
setObj graphemes.unit(41).name	"EE"
setObj graphemes.unit(42).name	"EI"
setObj graphemes.unit(43).name	"EU"
setObj graphemes.unit(44).name	"EW"
setObj graphemes.unit(45).name	"EY"
setObj graphemes.unit(46).name	"IE"
setObj graphemes.unit(47).name	"OA"
setObj graphemes.unit(48).name	"OE"
setObj graphemes.unit(49).name	"OI"
setObj graphemes.unit(50).name	"OO"
setObj graphemes.unit(51).name	"OU"
setObj graphemes.unit(52).name	"OW"
setObj graphemes.unit(53).name	"OY"
setObj graphemes.unit(54).name	"UE"
setObj graphemes.unit(55).name	"UI"
setObj graphemes.unit(56).name	"UY"
setObj graphemes.unit(57).name	"H"
setObj graphemes.unit(58).name	"R"
setObj graphemes.unit(59).name	"L"
setObj graphemes.unit(60).name	"M"
setObj graphemes.unit(61).name	"N"
setObj graphemes.unit(62).name	"B"
setObj graphemes.unit(63).name	"D"
setObj graphemes.unit(64).name	"G"
setObj graphemes.unit(65).name	"C"
setObj graphemes.unit(66).name	"X"
setObj graphemes.unit(67).name	"F"
setObj graphemes.unit(68).name	"V"
setObj graphemes.unit(69).name	"J"
setObj graphemes.unit(70).name	"S"
setObj graphemes.unit(71).name	"Z"
setObj graphemes.unit(72).name	"P"
setObj graphemes.unit(73).name	"T"
setObj graphemes.unit(74).name	"K"
setObj graphemes.unit(75).name	"Q"
setObj graphemes.unit(76).name	"BB"
setObj graphemes.unit(77).name	"CH"
setObj graphemes.unit(78).name	"CK"
setObj graphemes.unit(79).name	"DD"
setObj graphemes.unit(80).name	"DG"
setObj graphemes.unit(81).name	"FF"
setObj graphemes.unit(82).name	"GG"
setObj graphemes.unit(83).name	"GH"
setObj graphemes.unit(84).name	"GN"
setObj graphemes.unit(85).name	"KS"
setObj graphemes.unit(86).name	"LL"
setObj graphemes.unit(87).name	"NG"
setObj graphemes.unit(88).name	"NN"
setObj graphemes.unit(89).name	"PH"
setObj graphemes.unit(90).name	"PP"
setObj graphemes.unit(91).name	"PS"
setObj graphemes.unit(92).name	"RR"
setObj graphemes.unit(93).name	"SH"
setObj graphemes.unit(94).name	"SL"
setObj graphemes.unit(95).name	"SS"
setObj graphemes.unit(96).name	"TCH"
setObj graphemes.unit(97).name	"TH"
setObj graphemes.unit(98).name	"TS"
setObj graphemes.unit(99).name	"TT"
setObj graphemes.unit(100).name	"ZZ"
setObj graphemes.unit(101).name	"U"
setObj graphemes.unit(102).name	"E"
setObj graphemes.unit(103).name	"ES"
setObj graphemes.unit(104).name	"ED"
setObj phonemes.unit(0).name	"/s/"
setObj phonemes.unit(1).name	"/S/"
setObj phonemes.unit(2).name	"/C/"
setObj phonemes.unit(3).name	"/z/"
setObj phonemes.unit(4).name	"/Z/"
setObj phonemes.unit(5).name	"/j/"
setObj phonemes.unit(6).name	"/f/"
setObj phonemes.unit(7).name	"/v/"
setObj phonemes.unit(8).name	"/T/"
setObj phonemes.unit(9).name	"/D/"
setObj phonemes.unit(10).name	"/p/"
setObj phonemes.unit(11).name	"/b/"
setObj phonemes.unit(12).name	"/t/"
setObj phonemes.unit(13).name	"/d/"
setObj phonemes.unit(14).name	"/k/"
setObj phonemes.unit(15).name	"/g/"
setObj phonemes.unit(16).name	"/m/"
setObj phonemes.unit(17).name	"/n/"
setObj phonemes.unit(18).name	"/h/"
setObj phonemes.unit(19).name	"/l/"
setObj phonemes.unit(20).name	"/r/"
setObj phonemes.unit(21).name	"/w/"
setObj phonemes.unit(22).name	"/y/"
setObj phonemes.unit(23).name	"/a/"
setObj phonemes.unit(24).name	"/e/"
setObj phonemes.unit(25).name	"/i/"
setObj phonemes.unit(26).name	"/o/"
setObj phonemes.unit(27).name	"/u/"
setObj phonemes.unit(28).name	"/@/"
setObj phonemes.unit(29).name	"/^/"
setObj phonemes.unit(30).name	"/A/"
setObj phonemes.unit(31).name	"/E/"
setObj phonemes.unit(32).name	"/I/"
setObj phonemes.unit(33).name	"/O/"
setObj phonemes.unit(34).name	"/U/"
setObj phonemes.unit(35).name	"/W/"
setObj phonemes.unit(36).name	"/Y/"
setObj phonemes.unit(37).name	"/r/"
setObj phonemes.unit(38).name	"/l/"
setObj phonemes.unit(39).name	"/m/"
setObj phonemes.unit(40).name	"/n/"
setObj phonemes.unit(41).name	"/N/"
setObj phonemes.unit(42).name	"/b/"
setObj phonemes.unit(43).name	"/g/"
setObj phonemes.unit(44).name	"/d/"
setObj phonemes.unit(45).name	"/P/"
setObj phonemes.unit(46).name	"/K/"
setObj phonemes.unit(47).name	"/+/"
setObj phonemes.unit(48).name	"/s/"
setObj phonemes.unit(49).name	"/z/"
setObj phonemes.unit(50).name	"/f/"
setObj phonemes.unit(51).name	"/v/"
setObj phonemes.unit(52).name	"/p/"
setObj phonemes.unit(53).name	"/k/"
setObj phonemes.unit(54).name	"/t/"
setObj phonemes.unit(55).name	"/S/"
setObj phonemes.unit(56).name	"/Z/"
setObj phonemes.unit(57).name	"/T/"
setObj phonemes.unit(58).name	"/D/"
setObj phonemes.unit(59).name	"/C/"
setObj phonemes.unit(60).name	"/j/"
